==> haskell-hspec-expectations-lifted-0.10.0-260-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-B02jUPIbbnv1UUGGP1zNws
key:                  hspec-expectations-lifted-0.10.0-B02jUPIbbnv1UUGGP1zNws
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  7a877ca478f679aea708c60415b1a8f8
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-B02jUPIbbnv1UUGGP1zNws
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-LrMpsCa55zWGlw5k4mSqLh
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-lifted-0.10.0-262-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-expectations-lifted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-expectations-lifted
version:              0.10.0
visibility:           public
id:                   hspec-expectations-lifted-0.10.0-FtoASi5vuRDHZmRJ27PxtP
key:                  hspec-expectations-lifted-0.10.0-FtoASi5vuRDHZmRJ27PxtP
license:              MIT
copyright:            (c) 2011-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A version of hspec-expectations generalized to MonadIO
description:          A version of hspec-expectations generalized to MonadIO
category:             Testing
abi:                  0c3cadd2a82ff7e075b2daa18a7960d4
exposed:              True
exposed-modules:      Test.Hspec.Expectations.Lifted
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hspec-expectations-lifted-0.10.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-expectations-lifted
hs-libraries:         HShspec-expectations-lifted-0.10.0-FtoASi5vuRDHZmRJ27PxtP
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-HNF2nkkMHdZKPoFzwEmk0w
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hspec-expectations-lifted/html/hspec-expectations-lifted.haddock

haddock-html:         /usr/share/doc/haskell-hspec-expectations-lifted/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
